import { getLog } from './get-log';

const connect = async (pool, {
  Postgres,
  escapeId,
  escape,
  fullJitter,
  executeStatement,
  coercer
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName, _subscribersTableName;

  const log = getLog('connect');
  log.debug('configuring postgres client');
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    subscribersTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  subscribersTableName = (_subscribersTableName = subscribersTableName) !== null && _subscribersTableName !== void 0 ? _subscribersTableName : 'subscribers';
  const connection = new Postgres({
    keepAlive: false,
    connectionTimeoutMillis: 45000,
    idle_in_transaction_session_timeout: 45000,
    query_timeout: 45000,
    statement_timeout: 45000,
    ...connectionOptions
  });
  await connection.connect();
  Object.assign(pool, {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    connectionOptions,
    subscribersTableName,
    Postgres,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    escapeId,
    escape,
    connection
  });

  if (pool.executeStatement != null) {
    await pool.executeStatement('SELECT 0 AS "defunct"');
  }

  log.debug('connection to postgres databases established');
};

export default connect;
//# sourceMappingURL=connect.js.map