"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = require("./get-log");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

var _resourceErrors = require("./resource-errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropEvents = async ({
  databaseName,
  secretsTableName,
  eventsTableName,
  snapshotsTableName,
  subscribersTableName,
  executeStatement,
  escapeId
}) => {
  const log = (0, _getLog.getLog)('dropEvents');
  log.debug(`dropping event tables`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableNameAsId = escapeId(eventsTableName);
  const threadsTableNameAsId = escapeId(`${eventsTableName}-threads`);
  const freezeTableNameAsId = escapeId(`${eventsTableName}-freeze`);
  const snapshotsTableNameAsId = escapeId(snapshotsTableName);
  const incrementalImportTableAsId = escapeId(`${eventsTableName}-incremental-import`);
  const aggregateIdAndVersionIndexName = escapeId(`${eventsTableName}-aggregateIdAndVersion`);
  const aggregateIndexName = escapeId(`${eventsTableName}-aggregateId`);
  const aggregateVersionIndexName = escapeId(`${eventsTableName}-aggregateVersion`);
  const typeIndexName = escapeId(`${eventsTableName}-type`);
  const timestampIndexName = escapeId(`${eventsTableName}-timestamp`);
  const subscribersTableNameAsId = escapeId(subscribersTableName);
  const statements = [`DROP TABLE ${databaseNameAsId}.${eventsTableNameAsId}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIdAndVersionIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateVersionIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${typeIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${timestampIndexName}`, `DROP TABLE ${databaseNameAsId}.${threadsTableNameAsId}`, `DROP TABLE IF EXISTS ${databaseNameAsId}.${freezeTableNameAsId}`, `DROP TABLE ${databaseNameAsId}.${snapshotsTableNameAsId}`, `DROP TABLE IF EXISTS ${databaseNameAsId}.${incrementalImportTableAsId}`, `DROP TABLE ${databaseNameAsId}.${subscribersTableNameAsId}`];
  const errors = await (0, _executeSequence.default)(executeStatement, statements, log, error => {
    if ((0, _resourceErrors.isNotExistError)(error)) {
      return new _eventstoreBase.EventstoreResourceNotExistError(`postgresql adapter for database "${databaseName}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping events tables`);
  return errors;
};

var _default = dropEvents;
exports.default = _default;
//# sourceMappingURL=drop-events.js.map