"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _eventstoreBase = require("@resolve-js/eventstore-base");

const getCursorUntilEventTypes = async ({
  executeStatement,
  escapeId,
  escape,
  eventsTableName,
  shapeEvent,
  databaseName
}, cursor, untilEventTypes) => {
  if (untilEventTypes.length < 1) {
    throw new Error('Must define at least one event type');
  }

  const databaseNameAsId = escapeId(databaseName);
  const eventsTableAsId = escapeId(eventsTableName);
  const threadsTableAsId = escapeId(`${eventsTableName}-threads`);
  const vectorConditions = (0, _eventstoreBase.cursorToThreadArray)(cursor);
  const minThreadCounterConditions = `${vectorConditions.map((threadCounter, threadId) => `${escapeId('threadId')} = ${+threadId} AND ${escapeId('threadCounter')} >= ${+threadCounter}::${_constants.INT8_SQL_TYPE} `).join(' OR ')}`;
  const rows = await executeStatement(`SELECT "threadId", MIN("threadCounter") AS "threadCounter" FROM (
          SELECT "threadId", MIN("threadCounter") AS "threadCounter" FROM ${databaseNameAsId}.${eventsTableAsId} WHERE type IN 
          (${untilEventTypes.map(t => escape(t)).join(', ')}) 
          AND (${minThreadCounterConditions}) 
          GROUP BY "threadId"
          UNION ALL
          SELECT "threadId", "threadCounter" FROM ${databaseNameAsId}.${threadsTableAsId}) AS "union_table"
        GROUP BY "threadId"`);
  const threadCounters = (0, _eventstoreBase.initThreadArray)();

  for (const row of rows) {
    threadCounters[row.threadId] = +row.threadCounter;
  }

  return (0, _eventstoreBase.threadArrayToCursor)(threadCounters);
};

var _default = getCursorUntilEventTypes;
exports.default = _default;
//# sourceMappingURL=get-cursor-until-event-types.js.map