"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _eventstoreBase = require("@resolve-js/eventstore-base");

const loadEventsByCursor = async ({
  executeStatement,
  escapeId,
  escape,
  eventsTableName,
  databaseName,
  shapeEvent
}, {
  eventTypes,
  aggregateIds,
  cursor,
  limit
}) => {
  const injectString = value => `${escape(value)}`;

  const injectNumber = value => `${+value}`;

  const vectorConditions = (0, _eventstoreBase.cursorToThreadArray)(cursor);
  const queryConditions = [];

  if (eventTypes != null) {
    if (eventTypes.length === 0) {
      return (0, _eventstoreBase.emptyLoadEventsResult)(cursor);
    }

    queryConditions.push(`"type" IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    if (aggregateIds.length === 0) {
      return (0, _eventstoreBase.emptyLoadEventsResult)(cursor);
    }

    queryConditions.push(`"aggregateId" IN (${aggregateIds.map(injectString)})`);
  }

  const resultQueryCondition = `WHERE ${queryConditions.length > 0 ? `${queryConditions.join(' AND ')} AND (` : ''}
    ${vectorConditions.map((threadCounter, threadId) => `"threadId" = ${injectNumber(threadId)} AND "threadCounter" >= ${threadCounter}::${_constants.INT8_SQL_TYPE} `).join(' OR ')}
    ${queryConditions.length > 0 ? ')' : ''}`;
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableAsId = escapeId(eventsTableName);
  const sqlQuery = [`SELECT * FROM ${databaseNameAsId}.${eventsTableAsId}`, `${resultQueryCondition}`, `ORDER BY "timestamp" ASC, "threadCounter" ASC, "threadId" ASC`, `LIMIT ${+limit}`].join('\n');
  const rows = await executeStatement(sqlQuery);
  const events = [];

  for (const event of rows) {
    const threadId = +event.threadId;
    const threadCounter = +event.threadCounter;
    const oldThreadCounter = vectorConditions[threadId];
    vectorConditions[threadId] = Math.max(threadCounter + 1, oldThreadCounter);
    events.push(shapeEvent(event));
  }

  const nextConditions = (0, _eventstoreBase.threadArrayToCursor)(vectorConditions);
  return {
    cursor: nextConditions,
    events
  };
};

var _default = loadEventsByCursor;
exports.default = _default;
//# sourceMappingURL=load-events-by-cursor.js.map