import { Client as Postgres } from 'pg';
import type { AdapterPoolConnectedProps, AdapterPoolConnected, AdapterPoolPossiblyUnconnected, AdapterConfig } from '@resolve-js/eventstore-base';
export declare type Coercer = (value: {
    intValue: number;
    stringValue: string;
    bigIntValue: number;
    longValue: number;
    booleanValue: boolean;
} & {
    [key: string]: any;
}) => number | string | boolean;
declare type EscapeFunction = (source: string) => string;
declare type FullJitter = (retries: number) => number;
export declare type PostgresqlAdapterPoolConnectedProps = AdapterPoolConnectedProps & {
    Postgres: typeof Postgres;
    connectionOptions: any;
    databaseName: string;
    eventsTableName: string;
    snapshotsTableName: string;
    subscribersTableName: string;
    secretsTableName: string;
    fullJitter: FullJitter;
    coercer: Coercer;
    executeStatement: (sql: string) => Promise<any[]>;
    escapeId: EscapeFunction;
    escape: EscapeFunction;
    connection: Postgres;
};
export declare type PostgresqlAdapterConfig = AdapterConfig & {
    user?: string;
    database: string;
    port?: number;
    host?: string;
    password?: string;
    databaseName?: string;
    eventsTableName?: string;
    snapshotsTableName?: string;
    subscribersTableName?: string;
    secretsTableName?: string;
    [key: string]: any;
};
export declare type AdapterPool = AdapterPoolConnected<PostgresqlAdapterPoolConnectedProps>;
export declare type AdapterPoolPrimal = AdapterPoolPossiblyUnconnected<PostgresqlAdapterPoolConnectedProps>;
export declare type ConnectionDependencies = {
    Postgres: typeof Postgres;
    fullJitter: FullJitter;
    escapeId: EscapeFunction;
    escape: EscapeFunction;
    executeStatement: (pool: AdapterPool, sql: string) => Promise<any[]>;
    coercer: Coercer;
};
export declare type PostgresResourceConfig = {
    user: PostgresqlAdapterConfig['user'];
    database: PostgresqlAdapterConfig['database'];
    databaseName: PostgresqlAdapterConfig['databaseName'];
    host: PostgresqlAdapterConfig['host'];
    port: PostgresqlAdapterConfig['port'];
    password: PostgresqlAdapterConfig['password'];
};
export {};
